.. :changelog:

History
-------

1.0.1 (2014-03-04)
~~~~~~~~~~~~~~~~~~

* First release on pypi.

1.0 (2014-02-17)
~~~~~~~~~~~~~~~~~~

* First release on github.

Roadmap
-------

Since the project is in early stages no clear roadmap has been set but your 
suggestions are welcome.
